/*
 * Segment 2 (KEx),  SWE 2.1 LMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lms.empfang.dekoder;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.w3c.dom.Document;
import org.w3c.dom.NodeList;

import de.bsvrz.kex.lms.vew.RDSException;
import de.bsvrz.kex.lms.vew.RDSMeldung;
import de.bsvrz.kex.lms.vew.daten.RDSMeldungsDaten;

/**
 * Klasse zum Zugriff auf Dateien nach TIC-Info Spezifikation.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */
public class TICInfoDatei {

	/** TIC-Info Schema Location. */
	@SuppressWarnings("unused")
	private final String ticSchemaDatei = "de/bsvrz/kex/lms/vew/TIC Info XML.xsd";

	/** die Datei. */
	private final File ticDatei;

	/**
	 * Konstruktor aus Datei.
	 *
	 * @param datei
	 *            Datei
	 */
	public TICInfoDatei(final File datei) {
		ticDatei = datei;
	}

	/**
	 * Erzeugt aus der Datei eine Liste von enthaltenen RDS-Meldungen.
	 *
	 * @return Liste von Meldungsdaten
	 * @throws TICInfoDateiException
	 *             bei Fehlern
	 */
	public Collection<RDSMeldungsDaten> bildeMeldungen() throws TICInfoDateiException {
		final List<RDSMeldungsDaten> meldungen = new ArrayList<RDSMeldungsDaten>();

		final Document doc = getDocument();

		final NodeList nl = doc.getElementsByTagName(RDSMeldung.XML_ELEMENT_MELDUNG);

		for (int i = 0; i < nl.getLength(); i++) {
			try {
				final RDSMeldungsDaten meldung = new RDSMeldungsDaten(nl.item(i));
				meldungen.add(meldung);

			} catch (final RDSException e) {
				throw new TICInfoDateiException(e.getMessage());
			}
		}

		return meldungen;
	}

	/**
	 * Erzeugt das Document zur Datei. (Falls eine Verifikation der Datei gegen
	 * das Schema einmal möglich ist, sollte dies hier erfolgen)
	 *
	 * @return Document
	 * @throws TICInfoDateiException
	 *             bei Fehlern
	 */
	private Document getDocument() throws TICInfoDateiException {
		Document doc = null;

		final DocumentBuilderFactory docfactory = DocumentBuilderFactory.newInstance();

		// SchemaFactory schfactory =
		// SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
		// URL schemaurl = ClassLoader.getSystemResource(_ticSchemaDatei);
		try {
			// Validierung gegen Schema nicht möglich
			// Aussage Herr Kuske, Fa. GEWI
			// Schema ticschema = schfactory.newSchema(schemaurl);
			// docfactory.setSchema(ticschema);
			// docfactory.setValidating(true);

			final DocumentBuilder parser = docfactory.newDocumentBuilder();
			doc = parser.parse(ticDatei);
		} catch (final Exception e) {
			throw new TICInfoDateiException(e.getMessage());
		}

		return doc;
	}
}
