/*
 * Segment 2 (KEx),  SWE 2.1 LMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lms.vew.daten;

/**
 * Identifikation der Information.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */

public class RDSID extends AbstractRDSInfoElement {

	/**
	 * Identifikation der Information. TIC Info XML Element: IDT, eindeutige
	 * Identifikation der Information.
	 */
	private static final String XML_ELEMENT_ID = "IDT";

	/**
	 * Name der Organisation, welche die Meldung publiziert hat. TIC Info XML
	 * Element: IDOrganisation, Name der publizierenden Organisation.
	 */
	private static final String XML_ELEMENT_IDORGANISATION = "ORG";
	/**
	 * Laufende Nummer der Meldung. TIC Info XML Element: IDNumber, Fortlaufende
	 * Nummer der Meldung innerhalb der publizierenden Organisation
	 */
	private static final String XML_ELEMENT_IDNUMBER = "NUM";

	/**
	 * Name der Organisation, welche die Meldung publiziert hat.
	 */
	private final RDSText idOrganisation = new RDSText(RDSID.XML_ELEMENT_IDORGANISATION, "IDOrganisation");
	/**
	 * Laufende Nummer der Meldung.
	 */
	private final RDSText idNumber = new RDSText(RDSID.XML_ELEMENT_IDNUMBER, "IDNummer");

	/**
	 * Konstruktor.
	 */
	public RDSID() {
		super(RDSID.XML_ELEMENT_ID, "ID");
		appendChild(idOrganisation);
		appendChild(idNumber);
	}

	/**
	 * Gibt die IDNumber der Meldung zur&uuml;ck.
	 *
	 * @return IDNumber der Meldung
	 */
	protected String getIDNumber() {
		return idNumber.getText();
	}

	/**
	 * Gibt die IDOrganisation der Meldung zur&uuml;ck.
	 *
	 * @return IDOrganisation der Meldung
	 */
	protected String getIDOrganisation() {
		return idOrganisation.getText();
	}

	/**
	 * Setzt die IDNumber der Meldung.
	 *
	 * @param nummer
	 *            IDNumber
	 */
	protected void setIDNumber(final String nummer) {
		idNumber.setText(nummer);
	}

	/**
	 * Setzt die IDOrganisation der Meldung.
	 *
	 * @param organisation
	 *            IDOrganisation der Meldung
	 */
	protected void setIDOrganisation(final String organisation) {
		idOrganisation.setText(organisation);
	}

}
