/*
 * Segment 2 (KEx),  SWE 2.1 LMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lms.vew.daten;

import java.util.List;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.kex.lms.vew.RDSException;

/**
 * RDS-Infoelement Quantit&auml;tskennung.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */

public class RDSQuantitaetsKennung extends RDSReferenz {

	/**
	 * der Textwert in TIC.
	 */
	private String tictext = "DE";

	/**
	 * der Textwert im DaV.
	 */
	private String davtext = "rdsQuantität.LEN";

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public RDSQuantitaetsKennung(final String xmlName, final String davName) {
		super(xmlName, davName);
	}

	/**
	 * Findet die Pid des Quantit&auml;tsobjektes des Datenkataloges zu einer
	 * TIC-Quantit&auml;tskennung.
	 *
	 * @param ticQuantitaet
	 *            Quantit&auml;tskennung aus TIC-Datei
	 * @return PID des zugeh&ouml;rigen Objektes des Datenkataloges
	 * @throws RDSException
	 *             wenn kein Objekt bestimmt werden kann
	 */
	private String findeQuantitaetPid(final String ticQuantitaet) throws RDSException {
		final DataModel modell = DavDatenModell.getInstanz().getDataModel();

		final List<SystemObject> objekte = modell.getType("typ.rdsQuantität").getElements();

		final AttributeGroup atg = modell.getAttributeGroup("atg.rdsQuantität");

		for (final SystemObject objekt : objekte) {
			final Data d = objekt.getConfigurationData(atg);
			if (d != null) {
				final String kennung = d.getTextValue("Kennung").getText();
				if (kennung.equals(ticQuantitaet)) {
					return objekt.getPid();
				}
			}
		}

		throw new RDSException(
				"Das RDS-Quantitätsobjekt zur TIC-Quantität '" + ticQuantitaet + "' kann nicht bestimmt werden!");
	}

	/**
	 * Findet die Quantit&auml;tskennung f&uuml;r TIC zu einem
	 * DAV-Quantit&auml;tsobjekt.
	 *
	 * @param qkennungobjekt
	 *            DAV-Quantit&auml;tsobjekt
	 *
	 * @return zugeh&ouml;rige TIC-Quantit&auml;tskennung
	 */
	private String findeQuantitaetTIC(final String qkennungobjekt) {
		final DataModel modell = DavDatenModell.getInstanz().getDataModel();

		final SystemObject objekt = modell.getObject(qkennungobjekt);

		final AttributeGroup atg = modell.getAttributeGroup("atg.rdsQuantität");

		tictext = objekt.getConfigurationData(atg).getTextValue("Kennung").getText();

		return tictext;
	}

	@Override
	public void getDavDaten(final Data davdata) throws RDSException {
		davtext = davdata.getReferenceValue(getDavAttributName()).getSystemObjectPid();
	}

	@Override
	public void getXmlDaten(final Node node) {
		tictext = node.getTextContent();
	}

	@Override
	public void setDavDaten(final Data davdata) throws RDSException {
		davdata.getTextValue(getDavAttributName()).setText(findeQuantitaetPid(tictext));
	}

	@Override
	public void setXmlDaten(final Element element) {
		element.setTextContent(findeQuantitaetTIC(davtext));
	}
}
