/*
 * Segment 2 (KEx),  SWE 2.1 LMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lms.vew.daten;

import java.util.List;

/**
 * Daten einer Version der RDS-Meldung.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */

public class RDSVersion extends AbstractRDSInfoElement {

	/**
	 * Daten einer Version der RDS-Meldung. TIC Info XML Element: Version, Daten
	 * einer Version der RDS-Meldung.
	 */
	private static final String XML_ELEMENT_VERSION = "VER";

	/**
	 * Identifikator der Version. TIC Info XML Element: VersionGUID, globaler
	 * eindeutiger Identifikator der Version.
	 */
	private static final String XML_ELEMENT_VERSION_GUID = "VID";

	/**
	 * die Verkehrsinformationen der Version.
	 */
	RDSVerkehrsInformation verkehrsInformationen = new RDSVerkehrsInformation();

	/**
	 * die Verwaltungsinformationen der Version.
	 */
	RDSVerwaltungsInformation verwaltungsInformationen = new RDSVerwaltungsInformation();

	/**
	 * Konstruktor.
	 */
	public RDSVersion() {
		super(RDSVersion.XML_ELEMENT_VERSION, "Version");
		appendChild(new RDSText(RDSVersion.XML_ELEMENT_VERSION_GUID, "VersionGUID"));
		appendChild(verwaltungsInformationen);
		appendChild(verkehrsInformationen);
	}

	/**
	 * Gibt die Liste der Locationscodes zur&uuml;ck, die in der Version
	 * enthalten sind.
	 *
	 * @return Liste von Locationcodes
	 */
	public List<Integer> getLocationCodes() {
		return verkehrsInformationen.getLocationCodes();
	}

	/**
	 * Test, ob die Version g&uuml;ltig ist, d.h. der Ablaufzeitpunkt ist noch
	 * nicht erreicht.
	 *
	 * @return true wenn g&uuml;ltig sonst false
	 */
	public boolean istZeitGueltig() {
		return verwaltungsInformationen.istZeitGueltig();
	}

}
