/*
 * Segment 2 (KEx),  SWE 2.1 LMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lms.vew.daten;

import de.bsvrz.kex.lms.vew.daten.RDSStatus.RDS_StatusEN;

/**
 * Verwaltungsinformationen einer Version einer RDS-Meldung.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 */

public class RDSVerwaltungsInformation extends AbstractRDSInfoElement {

	/**
	 * Informationen zu &Auml;nderungen an Meldungen.
	 */
	class AenderungsInformation extends AbstractRDSInfoElement {

		/**
		 * TIC Info XML Element: Modifier, alle Informationen zu &Auml;nderungen
		 * an Meldungen.
		 */
		private static final String XML_ELEMENT_MODIFIER = "MOD";

		/**
		 * Name des Veranlassers der Modifikation. TIC Info XML Element:
		 * ModifierUserName, Name des Nutzers, der die Meldung ge&auml;ndert hat
		 * oder "system", wenn der TIC Server die &Auml;nderung vorgenommen hat.
		 */
		private static final String XML_ELEMENT_MODIFIERUSERNAME = "MUN";

		/**
		 * Kommentar des Veranlassers der &Auml;nderung. TIC Info XML Element:
		 * ModifierComment, Kommentar des Veranlassers zur &Auml;nderung.
		 */
		private static final String XML_ELEMENT_MODIFIERCOMMENT = "MCO";

		/**
		 * Modifikationszeitpunkt. TIC Info XML Element: ModifierTime, Exakter
		 * Zeitpunkt, an dem die Meldung ge&auml;ndert wurde.
		 */
		private static final String XML_ELEMENT_MODIFIERTIME = "MTI";

		/**
		 * Erzeugt ein neues Objekt mit Standardwerten.
		 */
		public AenderungsInformation() {
			super(AenderungsInformation.XML_ELEMENT_MODIFIER, "ÄnderungsInformationen");
			appendChild(new RDSText(AenderungsInformation.XML_ELEMENT_MODIFIERUSERNAME, "Veranlasser"));
			appendChild(new RDSZeitstempel(AenderungsInformation.XML_ELEMENT_MODIFIERTIME, "ModifikationsZeitpunkt"));
			appendChild(new RDSText(AenderungsInformation.XML_ELEMENT_MODIFIERCOMMENT, "ModifikationsKommentar"));
		}
	}

	/**
	 * Authorisierungsinformationen der Version.
	 */
	class Authorisierung extends AbstractRDSInfoElement {
		/**
		 * TIC Info XML Element: Authorizer.
		 */
		private static final String XML_ELEMENT_AUTHORIZER = "AUT";

		/**
		 * Organisationseinheit der authorisierenden Institution. TIC Info XML
		 * Element: AuthorizerOrganisationUnit, Organisationseinheit der
		 * authorisierenden Institution.
		 */
		private static final String XML_ELEMENT_AUTHORIZERORGANISATIONUNIT = "AOU";

		/**
		 * Authorisierender Nutzer. TIC Info XML Element: AuthorizerUserName,
		 * Name des Nutzers der authorisierenden Institution.
		 */
		private static final String XML_ELEMENT_AUTHORIZERUSERNAME = "AUN";

		/**
		 * Zeitpunkt der Authorisierung. TIC Info XML Element: AuthorizerTime,
		 * Exakter Zeitpunkt der Authorisierung dieser Version.
		 */
		private static final String XML_ELEMENT_AUTHORIZERTIME = "ATI";

		/**
		 * Kommentar zur Authorisierung. TIC Info XML Element:
		 * AuthorizerUserName, enh&auml;lt den Grund der Zur&uuml;ckweisung oder
		 * einen Kommentar zur Authorisierung.
		 */
		private static final String XML_ELEMENT_AUTHORIZERCOMMENT = "ACO";

		/**
		 * Ergebnis der Authorisierung. TIC Info XML Element: AuthorizerResult,
		 * Ergebniscode der Authorisierung.
		 */
		private static final String XML_ELEMENT_AUTHORIZERRESULT = "ARE";

		/**
		 * Konstruktor.
		 */
		public Authorisierung() {
			super(Authorisierung.XML_ELEMENT_AUTHORIZER, null);
			appendChild(new RDSZustand(Authorisierung.XML_ELEMENT_AUTHORIZERRESULT, "AuthorisierungsErgebnis"));
			appendChild(new RDSText(Authorisierung.XML_ELEMENT_AUTHORIZERORGANISATIONUNIT,
					"AuthorisierendeOrganisationsEinheit"));
			appendChild(new RDSText(Authorisierung.XML_ELEMENT_AUTHORIZERUSERNAME, "AuthorisierenderNutzer"));
			appendChild(new RDSText(Authorisierung.XML_ELEMENT_AUTHORIZERCOMMENT, "AuthorisierungsKommentar"));
			appendChild(new RDSZeitstempel(Authorisierung.XML_ELEMENT_AUTHORIZERTIME, "AuthorisierungsZeit"));
		}
	}

	/**
	 * TIC Info XML Element: Management, enth&auml;lt alle
	 * Verwaltungsinformationen zur Version.
	 */
	private static final String XML_ELEMENT_MANAGMENT = "MNG";

	/**
	 * Versionsnummer TIC Info XML Element: Versionnummer der Version.
	 */
	private static final String XML_ELEMENT_VERSIONNUMBER = "VNU";

	/**
	 * Zeitpunkt der Aktualisierung der Version. TIC Info XML Element:
	 * UpdateTime, Exakter Zeitpunkt der Aktualisierung der Version.
	 */
	private static final String XML_ELEMENT_UPDATETIME = "UPT";

	/**
	 * TIC Info XML Element: ExpiryTime, Exakter Zeitpunkt zu dem die
	 * G&uuml;ltigkeit der Version endet.
	 */
	private static final String XML_ELEMENT_EXPIRYTIME = "EXP";

	/**
	 * Zeitpunkt des Beginns der G&uuml;ltigkeit der Version. TIC Info XML
	 * Element: ActivateTime, Exakter Zeitpunkt zu dem die Version g&uuml;ltig
	 * wurde.
	 */
	private static final String XML_ELEMENT_ACTIVATETIME = "ACT";

	/**
	 * Zeitpunkt zum Erinnern des Benutzers. TIC Info XML Element: ReminderTime.
	 */
	private static final String XML_ELEMENT_REMINDERTIME = "REM";

	/**
	 * Zeitbereich zur Berechnung der Erinnerungszeit TIC Info XML Element:
	 * ReminderTimeOffset.
	 */
	private static final String XML_ELEMENT_REMINDERTIMEOFFSET = "REO";

	/**
	 * Definition der Benutzung von 'ErinnerungsZeit' und
	 * 'ErinnerungsZeitOffset'. TIC Info XML Element: ReminderTimeType,
	 * definiert die Bildung der 'ErinnerungsZeit' aus 'ErinnerungsZeit' und
	 * 'ErinnerungsZeitOffset'.
	 */
	private static final String XML_ELEMENT_REMINDERTIMETYPE = "REY";

	/**
	 * Zeitpunkt, an dem die erste Version g&uuml;ltig wurde. TIC Info XML
	 * Element: CreateTime, Exakter Zeitpunkt, an dem die erste Version dieser
	 * Meldung g&uuml;ltig wurde.
	 */
	private static final String XML_ELEMENT_CREATETIME = "CRT";

	/**
	 * Status der Version. TIC Info XML Element: Status.
	 */
	private static final String XML_ELEMENT_STATUS = "STA";

	/**
	 * Wichtung. TIC Info XML Element: Importance, interne Wichtung der Meldung
	 * in der LMS. 0: niedrigster Wert, 100: h&ouml;chster Wert
	 */
	private static final String XML_ELEMENT_IMPORTANCE = "IMP";

	/**
	 * Priorit&auml;t der Version. TIC Info XML Element: Priority, kennzeichnet
	 * die Priorit&auml;t der Version.
	 */
	private static final String XML_ELEMENT_PRIORITY = "PRI";

	/**
	 * Landeskennung TIC Info XML Element: Country.
	 */
	private static final String XML_ELEMENT_COUNTRY = "CTR";

	/**
	 * Zeitpunkt des Endes der G&uuml;ltigkeit der Version.
	 */
	private final RDSZeitstempel ablaufZeit = new RDSZeitstempel(RDSVerwaltungsInformation.XML_ELEMENT_EXPIRYTIME,
			"AblaufZeit");

	/**
	 * Die Versionsnummer der Meldung.
	 */
	private final RDSInteger versionsNummer = new RDSInteger(RDSVerwaltungsInformation.XML_ELEMENT_VERSIONNUMBER,
			"VersionsNummer");

	/**
	 * Der Status der Meldung.
	 */
	private final RDSStatus status = new RDSStatus(RDSVerwaltungsInformation.XML_ELEMENT_STATUS, "Status");

	/**
	 * Erzeugt ein neues Objekt mit Standardwerten.
	 */
	public RDSVerwaltungsInformation() {
		super(RDSVerwaltungsInformation.XML_ELEMENT_MANAGMENT, "VerwaltungsInformationen");
		appendChild(new Authorisierung());
		appendChild(versionsNummer);
		appendChild(new RDSZeitstempel(RDSVerwaltungsInformation.XML_ELEMENT_UPDATETIME, "AktualisierungsZeit"));
		appendChild(new RDSZeitstempel(RDSVerwaltungsInformation.XML_ELEMENT_ACTIVATETIME, "AktivierungsZeit"));

		appendChild(ablaufZeit);
		appendChild(new RDSZeitstempel(RDSVerwaltungsInformation.XML_ELEMENT_REMINDERTIME, "ErinnerungsZeit"));
		appendChild(
				new RDSZeitdauer(RDSVerwaltungsInformation.XML_ELEMENT_REMINDERTIMEOFFSET, "ErinnerungsZeitOffset"));
		appendChild(new RDSZustand(RDSVerwaltungsInformation.XML_ELEMENT_REMINDERTIMETYPE, "ErinnerungsTyp"));
		appendChild(new RDSZeitstempel(RDSVerwaltungsInformation.XML_ELEMENT_CREATETIME, "ErzeugungsZeit"));
		appendChild(new AenderungsInformation());
		appendChild(status);
		appendChild(new RDSInteger(RDSVerwaltungsInformation.XML_ELEMENT_IMPORTANCE, "Wichtung"));
		appendChild(new RDSZustand(RDSVerwaltungsInformation.XML_ELEMENT_PRIORITY, "Priorität"));
		appendChild(new RDSLandeskennung(RDSVerwaltungsInformation.XML_ELEMENT_COUNTRY, "LandesKennung"));
	}

	/**
	 * Gibt den Status der Meldung zur&uuml;ck.
	 *
	 * @return Status
	 */
	public RDS_StatusEN getMeldungsStatus() {
		return status.getRDSMeldungsStatus();
	}

	/**
	 * Gibt die Versionsnummer der Meldung zur&uuml;ck.
	 *
	 * @return Versionsnummer
	 */
	public int getVersion() {
		return versionsNummer.wert;
	}

	/**
	 * Test, ob die Version (noch) zeitlich g&uuml;ltig ist.
	 *
	 * @return true, wenn die Version (noch) g&uuml;ltig ist, sonst false
	 */
	public boolean istZeitGueltig() {
		return System.currentTimeMillis() < ablaufZeit.zeitstempel;
	}

	/**
	 * Setzt die Ablaufzeit der Meldung.
	 *
	 * @param neueAblaufzeit
	 *            neue Ablaufzeit
	 */
	public void setAblaufzeit(final long neueAblaufzeit) {
		ablaufZeit.zeitstempel = neueAblaufzeit;
	}

	/**
	 * Setzt den Status der Meldung.
	 *
	 * @param neuerstatus
	 *            neuer Status
	 */
	public void setMeldungsStatus(final RDS_StatusEN neuerstatus) {
		status.setRDSMeldungsStatus(neuerstatus);
	}
}
